pub struct TestMintWrapper {
pub label: String,
pub mint_wrapper: AccountRef<MintWrapper>,
pub mint_wrapper_base: Keypair,
pub reward_token_mint: AccountRef<Mint>,
pub authority: Pubkey,
}Expand description
Test mint wrapper with labeled accounts
Fields
label: Stringmint_wrapper: AccountRef<MintWrapper>mint_wrapper_base: Keypairreward_token_mint: AccountRef<Mint>Implementations
Sourceimpl TestMintWrapper
impl TestMintWrapper
Sourcepub fn new(env: &mut TestSVM, label: &str, authority: &Keypair) -> Result<Self>
pub fn new(env: &mut TestSVM, label: &str, authority: &Keypair) -> Result<Self>
Create a new mint wrapper with the specified label and authority
Sourcepub fn create_minter(
&self,
env: &mut TestSVM,
minter_authority: &Pubkey,
allowance: u64,
admin: &Keypair,
) -> Result<AccountRef<Minter>>
pub fn create_minter( &self, env: &mut TestSVM, minter_authority: &Pubkey, allowance: u64, admin: &Keypair, ) -> Result<AccountRef<Minter>>
Create a minter for the specified authority with the given allowance
Transfer mint wrapper authority to a new authority
Accept mint wrapper authority transfer